<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Kompany
 * @since Kompany 1.0.0
 * @return array An array of default values
 */

function kompany_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$kompany_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#666',
		'header_txt_logo_extra'			=> 'show-all',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		//body typography
		'body_font_family'			=> 'Muli',
		'body_font_weight'			=> 300,
		'body_font_size'			=> 16,
		'body_font_style'			=> 'normal',
		'body_text_transform'		=> 'none',

		//h1 typography
		'heading_h1_font_family'		=> 'Raleway',
		'heading_h1_font_weight'		=> 300,
		'heading_h1_text_transform'		=> 'none',
		'heading_h1_font_style'			=> 'normal',

		//h2 typography
		'heading_h2_font_family'		=> 'Raleway',
		'heading_h2_font_weight'		=> 700,
		'heading_h2_text_transform'		=> 'none',
		'heading_h2_font_style'			=> 'normal',

		//h3 typography
		'heading_h3_font_family'		=> 'Raleway',
		'heading_h3_font_weight'		=> 700,
		'heading_h3_text_transform'		=> 'none',
		'heading_h3_font_style'			=> 'normal',

		//h4 typography
		'heading_h4_font_family'		=> 'Raleway',
		'heading_h4_font_weight'		=> 700,
		'heading_h4_text_transform'		=> 'none',
		'heading_h4_font_style'			=> 'normal',

		//h5 typography
		'heading_h5_font_family'		=> 'Raleway',
		'heading_h5_font_weight'		=> 700,
		'heading_h5_text_transform'		=> 'none',
		'heading_h5_font_style'			=> 'normal',

		//h6 typography
		'heading_h6_font_family'		=> 'Raleway',
		'heading_h6_font_weight'		=> 700,
		'heading_h6_text_transform'		=> 'none',
		'heading_h6_font_style'			=> 'normal',

		//p typography
		'heading_p_font_family'			=> 'Muli',
		'heading_p_font_weight'			=> 400,
		'heading_p_text_transform'		=> 'none',
		'heading_p_font_style'			=> 'normal',

		//button
		'button_background_color'		=> '#e5f8fc',
		'button_text_color'				=> '#00afe9',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'kompany' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'all_sortable' 						=> 'header_content,about,service,cta,special,team,contact,latest_blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'kompany' ),
		'single_post_hide_banner'		=> false,
		'hide_banner'					=> false,			
		'blog_page_column'				=> 'col-2',
		'blog_page_post_btn' 			=> esc_html__( 'Read More', 'kompany' ),

		// single post theme options
		'single_post_hide_date' 			=> false,
		'single_post_hide_category'			=> false,

		/* Front Page */

		//top bar
		'topbar_section_enable'			=> false,
		'social_menu_enable'			=> true,

		//header content
		'header_content_section_enable'		=> false,
		'header_content_sub_title'			=> esc_html__( 'Hello, We’re', 'kompany' ),
		'header_content_title'				=> esc_html__( 'Corporate Design Theme', 'kompany' ),

		// about
		'about_section_enable'			=> false,
		'about_btn_title'				=> esc_html__( 'Get Started', 'kompany' ),

		// service
		'service_section_enable'		=> false,
		'service_title'					=> esc_html('Our Services', 'kompany'),

		// cta
		'cta_section_enable'		=> false,
		'cta_sub_title'				=> esc_html__( 'You can trust us for', 'kompany' ),
		'cta_btn_title'				=> esc_html__( 'More Details', 'kompany' ),

		// special
		'special_section_enable'		=> false,
		'special_title'					=> esc_html__( 'We help you to grow your firm.', 'kompany' ),
		'special_sub_title'				=> esc_html__( 'Dear All,', 'kompany' ),
		'special_excerpt_length'		=> 60,

		// team
		'team_section_enable'		=> false,
		'team_title'				=> esc_html('Our Team', 'kompany'),
		'team_sub_title'			=> esc_html('We are in a small market. We are not in San Francisco, Paris, or New York. I’ve seen that smaller markets are two to three years...', 'kompany'),
		'team_btn'					=> esc_html('View All Members', 'kompany'),

		// contact
		'contact_section_enable'		=> false,
		'contact_subtitle'				=> esc_html__( 'Let’s Talk', 'kompany' ),
		'contact_btn_title'				=> esc_html__( 'Contact Us', 'kompany' ),

		// latest_blog
		'latest_blog_section_enable'	=> false,
		'latest_blog_content_type'		=> 'category',
		'latest_blog_title'				=> esc_html__( 'News & Announcement', 'kompany' ),

		// gallery
		'gallery_section_enable'		=> false,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 6,
		'gallery_title'					=> esc_html__( 'College Events', 'kompany' ),
		'gallery_subtitle'				=> esc_html__( 'Portfolio', 'kompany' ),


		//popular products
		'popular_products_section_enable'	=> false,
		'popular_products_content_type'		=> 'product-category',
		'popular_products_count'			=> 4,
		'popular_products_title'			=> esc_html__( 'Womens Accessories', 'kompany' ),
		'popular_products_sub_title'		=> esc_html__( 'Collections', 'kompany' ),

	);

	$output = apply_filters( 'kompany_default_theme_options', $kompany_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}