<?php
/**
 * Contact Section options
 *
 * @package Theme Palace
 * @subpackage Kompany
 * @since Kompany 1.0.0
 */

// Add Contact section
$wp_customize->add_section( 'kompany_contact_section', array(
	'title'             => esc_html__( 'Contact','kompany' ),
	'description'       => esc_html__( 'Contact Section options.', 'kompany' ),
	'panel'             => 'kompany_front_page_panel',
) );

// Contact content enable control and setting
$wp_customize->add_setting( 'kompany_theme_options[contact_section_enable]', array(
	'default'			=> 	$options['contact_section_enable'],
	'sanitize_callback' => 'kompany_sanitize_switch_control',
) );

$wp_customize->add_control( new Kompany_Switch_Control( $wp_customize, 'kompany_theme_options[contact_section_enable]', array(
	'label'             => esc_html__( 'Contact Section Enable', 'kompany' ),
	'section'           => 'kompany_contact_section',
	'on_off_label' 		=> kompany_switch_options(),
) ) );

// contact title setting and control
$wp_customize->add_setting( 'kompany_theme_options[contact_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['contact_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'kompany_theme_options[contact_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'kompany' ),
	'section'        	=> 'kompany_contact_section',
	'active_callback' 	=> 'kompany_is_contact_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kompany_theme_options[contact_subtitle]', array(
		'selector'            => '#kompany_contact_section p.section-subtitle',
		'settings'            => 'kompany_theme_options[contact_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kompany_contact_subtitle_partial',
    ) );
}

// contact pages drop down chooser control and setting
$wp_customize->add_setting( 'kompany_theme_options[contact_content_page]', array(
	'sanitize_callback' => 'kompany_sanitize_page',
) );

$wp_customize->add_control( new Kompany_Dropdown_Chooser( $wp_customize, 'kompany_theme_options[contact_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'kompany' ),
	'section'           => 'kompany_contact_section',
	'choices'			=> kompany_page_choices(),
	'active_callback'	=> 'kompany_is_contact_section_enable',
) ) );


// contact btn title setting and control
$wp_customize->add_setting( 'kompany_theme_options[contact_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['contact_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'kompany_theme_options[contact_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'kompany' ),
	'section'        	=> 'kompany_contact_section',
	'active_callback' 	=> 'kompany_is_contact_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kompany_theme_options[contact_btn_title]', array(
		'selector'            => '#kompany_contact_section .read-more a.btn',
		'settings'            => 'kompany_theme_options[contact_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kompany_contact_btn_title_partial',
    ) );
}