<?php
/**
 * CTA Section options
 *
 * @package Theme Palace
 * @subpackage Kompany
 * @since Kompany 1.0.0
 */

// Add CTA section
$wp_customize->add_section( 'kompany_cta_section', array(
	'title'             => esc_html__( 'CTA','kompany' ),
	'description'       => esc_html__( 'CTA Section options.', 'kompany' ),
	'panel'             => 'kompany_front_page_panel',
) );

// CTA content enable control and setting
$wp_customize->add_setting( 'kompany_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'kompany_sanitize_switch_control',
) );

$wp_customize->add_control( new Kompany_Switch_Control( $wp_customize, 'kompany_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'kompany' ),
	'section'           => 'kompany_cta_section',
	'on_off_label' 		=> kompany_switch_options(),
) ) );

// cta btn title setting and control
$wp_customize->add_setting( 'kompany_theme_options[cta_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_sub_title'],
) );

$wp_customize->add_control( 'kompany_theme_options[cta_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title: ', 'kompany' ),
	'section'        	=> 'kompany_cta_section',
	'active_callback' 	=> 'kompany_is_cta_section_enable',
	'type'				=> 'text',
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'kompany_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'kompany_sanitize_page',
) );

$wp_customize->add_control( new Kompany_Dropdown_Chooser( $wp_customize, 'kompany_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'kompany' ),
	'section'           => 'kompany_cta_section',
	'choices'			=> kompany_page_choices(),
	'active_callback'	=> 'kompany_is_cta_section_enable',
) ) );

// cta btn title setting and control
$wp_customize->add_setting( 'kompany_theme_options[cta_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'kompany_theme_options[cta_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'kompany' ),
	'section'        	=> 'kompany_cta_section',
	'active_callback' 	=> 'kompany_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kompany_theme_options[cta_btn_title]', array(
		'selector'            => '#kompany_cta_section div.read-more a',
		'settings'            => 'kompany_theme_options[cta_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kompany_cta_btn_title_partial',
    ) );
}