<?php
/**
 * Special Section options
 *
 * @package Theme Palace
 * @subpackage Kompany
 * @since Kompany 1.0.0
 */

// Add Special section
$wp_customize->add_section( 'kompany_special_section', array(
	'title'             => esc_html__( 'Special','kompany' ),
	'description'       => esc_html__( 'Special Section options.', 'kompany' ),
	'panel'             => 'kompany_front_page_panel',
) );

// Special content enable control and setting
$wp_customize->add_setting( 'kompany_theme_options[special_section_enable]', array(
	'default'			=> 	$options['special_section_enable'],
	'sanitize_callback' => 'kompany_sanitize_switch_control',
) );

$wp_customize->add_control( new Kompany_Switch_Control( $wp_customize, 'kompany_theme_options[special_section_enable]', array(
	'label'             => esc_html__( 'Special Section Enable', 'kompany' ),
	'section'           => 'kompany_special_section',
	'on_off_label' 		=> kompany_switch_options(),
) ) );

// special sub_title setting and control
$wp_customize->add_setting( 'kompany_theme_options[special_sub_title]',
	array(
		'default'       		=> $options['special_sub_title'],
		'sanitize_callback'		=> 'sanitize_text_field',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'kompany_theme_options[special_sub_title]',
    array(
		'label'      			=> esc_html__( 'Section Sub Title', 'kompany' ),
		'section'    			=> 'kompany_special_section',
		'type'		 			=> 'text',
		'active_callback'		=> 'kompany_is_special_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kompany_theme_options[special_sub_title]', array(
		'selector'            => '#kompany_special_section p.section-subtitle',
		'settings'            => 'kompany_theme_options[special_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kompany_special_sub_title_partial',
    ) );
}

// special title setting and control
$wp_customize->add_setting( 'kompany_theme_options[special_title]',
	array(
		'default'       		=> $options['special_title'],
		'sanitize_callback'		=> 'sanitize_text_field',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'kompany_theme_options[special_title]',
    array(
		'label'      			=> esc_html__( 'Section Title', 'kompany' ),
		'section'    			=> 'kompany_special_section',
		'type'		 			=> 'text',
		'active_callback'		=> 'kompany_is_special_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kompany_theme_options[special_title]', array(
		'selector'            => '#kompany_special_section h2.section-title',
		'settings'            => 'kompany_theme_options[special_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kompany_special_title_partial',
    ) );
}

// special pages drop down chooser control and setting
$wp_customize->add_setting( 'kompany_theme_options[special_content_page]', array(
	'sanitize_callback' => 'kompany_sanitize_page',
) );

$wp_customize->add_control( new Kompany_Dropdown_Chooser( $wp_customize, 'kompany_theme_options[special_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'kompany' ),
	'section'           => 'kompany_special_section',
	'choices'			=> kompany_page_choices(),
	'active_callback'	=> 'kompany_is_special_section_enable',
) ) );