<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Kompany
 * @since Kompany 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function kompany_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'kompany' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function kompany_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'kompany' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function kompany_event_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'kompany' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function kompany_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'kompany' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

function kompany_product_choices() {
    $full_product_list = array();
    $product_id = array();
    $loop = new WP_Query(array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1));
    while ($loop->have_posts()) : $loop->the_post();
        $product_id[] = get_the_id();
    endwhile;
    wp_reset_postdata();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'kompany' );
    foreach ( $product_id  as $id ) {
        $choices[ $id ] = get_the_title( $id );
    }
    return  $choices;
}


if ( ! function_exists( 'kompany_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function kompany_selected_sidebar() {
        $kompany_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'kompany' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'kompany' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'kompany' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'kompany' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'kompany' ),
        );

        $output = apply_filters( 'kompany_selected_sidebar', $kompany_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'kompany_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function kompany_site_layout() {
        $kompany_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'kompany_site_layout', $kompany_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'kompany_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function kompany_global_sidebar_position() {
        $kompany_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'kompany_global_sidebar_position', $kompany_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'kompany_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function kompany_sidebar_position() {
        $kompany_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'kompany_sidebar_position', $kompany_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'kompany_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function kompany_pagination_options() {
        $kompany_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'kompany' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'kompany' ),
        );

        $output = apply_filters( 'kompany_pagination_options', $kompany_pagination_options );

        return $output;
    }
endif;


if ( ! function_exists( 'kompany_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function kompany_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'kompany' ),
            'off'       => esc_html__( 'Disable', 'kompany' )
        );
        return apply_filters( 'kompany_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'kompany_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function kompany_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'kompany' ),
            'off'       => esc_html__( 'No', 'kompany' )
        );
        return apply_filters( 'kompany_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'kompany_heading_tags' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function kompany_heading_tags() {
        
        $kompany_heading_tags = array(
			'h1'	=> esc_html__('H1', 'kompany'),
			'h2'	=> esc_html__('H2', 'kompany'),
			'h3'	=> esc_html__('H3', 'kompany'),
			'h4'	=> esc_html__('H4', 'kompany'),
			'h5'	=> esc_html__('H5', 'kompany'),
			'h6'	=> esc_html__('H6', 'kompany'),
			'p'		=> esc_html__('Paragraph', 'kompany'),
		);

        $output = apply_filters( 'kompany_heading_tags', $kompany_heading_tags );


        return $output;
    }
endif;