<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Kompany
 * @since Kompany 1.0.0
 */
if ( ! function_exists( 'kompany_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Kompany 1.0.0
    */
    function kompany_add_about_section() {
    	$options = kompany_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'kompany_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'kompany_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        kompany_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'kompany_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Kompany 1.0.0
    * @param array $input about section details.
    */
    function kompany_get_about_section_details( $input ) {
        $options = kompany_get_theme_options();
        
        $content = array();
         $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    ); 

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = kompany_trim_content( 20 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'kompany_filter_about_section_details', 'kompany_get_about_section_details' );


if ( ! function_exists( 'kompany_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Kompany 1.0.0
   *
   */
   function kompany_render_about_section( $content_details = array() ) {
        $options = kompany_get_theme_options();
        $about_btn_title = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 
        ?>
        <?php foreach ( $content_details as $content ) : ?>
        
            <div id="kompany_about_section" class="relative page-section same-background">
                <div class="wrapper">
                    <article>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"></div><!-- .featured-image -->

                        <div class="entry-container">
                            <?php if( !empty( $content['title'] ) ): ?>
                                <header class="entry-header">
                                    <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                </header><!-- .entry-header -->
                            <?php endif; ?>

                            <?php if( !empty( $content['excerpt'] ) ): ?>
                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->
                        <?php endif; ?>

                        <?php if( !empty( $content['url'] ) && !empty( $about_btn_title ) ): ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $about_btn_title ); ?></a>
                            </div><!-- .read-more -->
                        <?php endif; ?>
                    </div><!-- .entry-container -->
                </article>
            </div><!-- .wrapper -->
        </div><!-- #about -->

    <?php 
    endforeach;
}
endif;