<?php
/**
 * Contact section
 *
 * This is the template for the content of contact section
 *
 * @package Theme Palace
 * @subpackage Kompany
 * @since Kompany 1.0.0
 */
if ( ! function_exists( 'kompany_add_contact_section' ) ) :
    /**
    * Add contact section
    *
    *@since Kompany 1.0.0
    */
    function kompany_add_contact_section() {
      $options = kompany_get_theme_options();
        // Check if contact is enabled on frontpage
        $contact_enable = apply_filters( 'kompany_section_status', true, 'contact_section_enable' );

        if ( true !== $contact_enable ) {
            return false;
        }
        // Get contact section details
        $section_details = array();
        $section_details = apply_filters( 'kompany_filter_contact_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render contact section now.
        kompany_render_contact_section( $section_details );
    }
endif;

if ( ! function_exists( 'kompany_get_contact_section_details' ) ) :
    /**
    * contact section details.
    *
    * @since Kompany 1.0.0
    * @param array $input contact section details.
    */
    function kompany_get_contact_section_details( $input ) {
        $options = kompany_get_theme_options();
        
        $content = array();
         $page_id = ! empty( $options['contact_content_page'] ) ? $options['contact_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = kompany_trim_content( 20 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// contact section content details.
add_filter( 'kompany_filter_contact_section_details', 'kompany_get_contact_section_details' );


if ( ! function_exists( 'kompany_render_contact_section' ) ) :
  /**
   * Start contact section
   *
   * @return string contact content
   * @since Kompany 1.0.0
   *
   */
   function kompany_render_contact_section( $content_details = array() ) {
        $options = kompany_get_theme_options();
        $contact_subtitle = ! empty( $options['contact_subtitle'] ) ? $options['contact_subtitle'] : '';
        $contact_btn_title = ! empty( $options['contact_btn_title'] ) ? $options['contact_btn_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 
        ?>
        <?php foreach ( $content_details as $content ) : ?>
        
          <div id="kompany_contact_section" class="page-section" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
            <div class="wrapper">
              <div class="contact-wrapper">
                <div class="section-header-wrapper clear">
                  <div class="entry-container clear">
                    <div class="section-header">
                      <?php if( !empty( $contact_subtitle ) ): ?>
                        <p class="section-subtitle"><?php echo esc_html( $contact_subtitle ); ?></p>
                      <?php endif; ?>
                      <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                    </div><!-- .section-header -->

                    <?php if( !empty( $content['url'] ) && !empty( $contact_btn_title ) ): ?>
                    <div class="read-more">
                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $contact_btn_title ); ?></a>
                    </div>
                  <?php endif; ?>
                  </div>
                  <div class="section-content">
                  <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                  </div>
                </div>
              </div>
            </div><!-- .wrapper -->
          </div><!-- #contact -->

    <?php 
    endforeach;
}
endif;