<?php
/**
 * CTA section
 *
 * This is the template for the content of cta section
 *
 * @package Theme Palace
 * @subpackage Kompany
 * @since Kompany 1.0.0
 */
if ( ! function_exists( 'kompany_add_cta_section' ) ) :
    /**
    * Add cta section
    *
    *@since Kompany 1.0.0
    */
    function kompany_add_cta_section() {
        $options = kompany_get_theme_options();
        // Check if cta is enabled on frontpage
        $cta_enable = apply_filters( 'kompany_section_status', true, 'cta_section_enable' );

        if ( true !== $cta_enable ) {
            return false;
        }
        // Get cta section details
        $section_details = array();
        $section_details = apply_filters( 'kompany_filter_cta_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render cta section now.
        kompany_render_cta_section( $section_details );
    }
endif;

if ( ! function_exists( 'kompany_get_cta_section_details' ) ) :
    /**
    * cta section details.
    *
    * @since Kompany 1.0.0
    * @param array $input cta section details.
    */
    function kompany_get_cta_section_details( $input ) {
        $options = kompany_get_theme_options();
        
        $content = array();
         $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );  

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = kompany_trim_content( 30 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// cta section content details.
add_filter( 'kompany_filter_cta_section_details', 'kompany_get_cta_section_details' );


if ( ! function_exists( 'kompany_render_cta_section' ) ) :
  /**
   * Start cta section
   *
   * @return string cta content
   * @since Kompany 1.0.0
   *
   */
   function kompany_render_cta_section( $content_details = array() ) {
        $options = kompany_get_theme_options();
        $cta_sub_title = ! empty( $options['cta_sub_title'] ) ? $options['cta_sub_title'] : '';
        $cta_btn_title = ! empty( $options['cta_btn_title'] ) ? $options['cta_btn_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 
        ?>
        <?php foreach ( $content_details as $content ): ?>
    
        <div id="kompany_cta_section" class="relative page-section same-background">
                <div class="wrapper">
                    <article>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"></div><!-- .featured-image -->

                        <div class="entry-container">
                            <div class="section-header">
                                <h2 class="section-title"><?php echo esc_html( $cta_sub_title ); ?> <span><?php echo esc_html( $content['title'] ); ?></span></h2>
                            </div><!-- .section-header -->

                            <div class="section-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .section-content -->

                            <?php if( !empty( $cta_btn_title ) ): ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $cta_btn_title ); ?></a>
                            </div><!-- .read-more -->
                        <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #about -->

    <?php 
    endforeach;
}
endif;