<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Kompany
 * @since Kompany 1.0.0
 */
if ( ! function_exists( 'kompany_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Kompany 1.0.0
    */
    function kompany_add_service_section() {
        $options = kompany_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'kompany_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'kompany_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        kompany_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'kompany_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Kompany 1.0.0
    * @param array $input service section details.
    */
    function kompany_get_service_section_details( $input ) {
        $options = kompany_get_theme_options();
        
        $content = array();
        $post_ids = array();
        for ( $i = 1; $i <= 2; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => 2,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );

        // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = kompany_trim_content( 25 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'kompany_filter_service_section_details', 'kompany_get_service_section_details' );


if ( ! function_exists( 'kompany_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Kompany 1.0.0
   *
   */
   function kompany_render_service_section( $content_details = array() ) {
        $options = kompany_get_theme_options();
        $service_title = ! empty( $options['service_title'] ) ? $options['service_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 
        ?> 

        <div id="kompany_service_section" class="relative page-section same-background">
                <div class="wrapper">
                <?php if (!empty( $options['service_title'] )) { ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['service_title'] ); ?></h2>
                    </div><!-- .section-header -->
                <?php } ?>
                    

                    <div class="section-content col-2 clear">
                        
                        <?php foreach ($content_details as $content ): ?>

                            <article>
                            <div class="service-item">
                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .service-item -->
                        </article>
                            
                        <?php endforeach ?>

                    </div><!-- .col-2 -->
                </div><!-- .wrapper -->
            </div><!-- #service-section -->

    <?php }
endif;