<?php
/**
 * About section
 *
 * This is the template for the content of special section
 *
 * @package Theme Palace
 * @subpackage Kompany
 * @since Kompany 1.0.0
 */
if ( ! function_exists( 'kompany_add_special_section' ) ) :
    /**
    * Add special section
    *
    *@since Kompany 1.0.0
    */
    function kompany_add_special_section() {
    	$options = kompany_get_theme_options();
        // Check if special is enabled on frontpage
        $special_enable = apply_filters( 'kompany_section_status', true, 'special_section_enable' );

        if ( true !== $special_enable ) {
            return false;
        }
        // Get special section details
        $section_details = array();
        $section_details = apply_filters( 'kompany_filter_special_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render special section now.
        kompany_render_special_section( $section_details );
    }
endif;

if ( ! function_exists( 'kompany_get_special_section_details' ) ) :
    /**
    * special section details.
    *
    * @since Kompany 1.0.0
    * @param array $input special section details.
    */
    function kompany_get_special_section_details( $input ) {
        $options = kompany_get_theme_options();
        
        $content = array();
        $page_id = ! empty( $options['special_content_page'] ) ? $options['special_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    ); 

         // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = kompany_trim_content( 60 );
                    $page_post['url']       = get_the_permalink();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// special section content details.
add_filter( 'kompany_filter_special_section_details', 'kompany_get_special_section_details' );


if ( ! function_exists( 'kompany_render_special_section' ) ) :
  /**
   * Start special section
   *
   * @return string special content
   * @since Kompany 1.0.0
   *
   */
   function kompany_render_special_section( $content_details = array() ) {
        $options = kompany_get_theme_options();

        $subtitle = !empty( $options['special_sub_title'] ) ? $options['special_sub_title'] : '';
        $title = !empty( $options['special_title'] ) ? $options['special_title'] : '';
        if ( empty( $content_details ) ) {
            return;
        } 
        ?>
        <?php foreach ( $content_details as $content ) : ?>

            <div id="kompany_special_section" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-header">
                        <?php if( !empty( $subtitle ) ): ?>
                            <p class="section-subtitle"><?php echo esc_html( $subtitle ); ?></p>
                        <?php endif;

                        if( !empty( $title ) ):
                            ?>
                        <h2 class="section-title"><?php echo esc_html( $title ); ?></h2>

                    <?php endif; ?>

                </div><!-- .section-header -->

                <div class="section-content">
                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                </div>

                <header class="entry-header">
                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>" tabindex="0"><?php echo esc_html( $content['title'] ); ?></a></h2>
                </header>
            </div><!-- .wrapper -->
        </div><!-- #about -->

    <?php 
    endforeach;
}
endif;