<?php
/**
 * team section
 *
 * This is the template for the content of team section
 *
 * @team Theme Palace
 * @subteam Kompany
 * @since Kompany 1.0.0
 */
if ( ! function_exists( 'kompany_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since Kompany 1.0.0
    */
    function kompany_add_team_section() {
        $options = kompany_get_theme_options();
        // Check if team is enabled on frontpage
        $team_enable = apply_filters( 'kompany_section_status', true, 'team_section_enable' );


        if ( true !== $team_enable ) {
            return false;
        }
        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'kompany_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        kompany_render_team_section( $section_details );
    }
endif;

if ( ! function_exists( 'kompany_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since Kompany 1.0.0
    * @param array $input team section details.
    */
    function kompany_get_team_section_details( $input ) {
        $options = kompany_get_theme_options();
        
        $content = array();
        $page_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['team_content_page_' . $i] ) )
                        $page_ids[] = $options['team_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    );

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'kompany_filter_team_section_details', 'kompany_get_team_section_details' );


if ( ! function_exists( 'kompany_render_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since Kompany 1.0.0
   *
   */
   function kompany_render_team_section( $content_details = array() ) {
        $options = kompany_get_theme_options();
        $team_title = ! empty( $options['team_title'] ) ? $options['team_title'] : '';
        $team_sub_title = ! empty( $options['team_sub_title'] ) ? $options['team_sub_title'] : '';
        $team_btn = ! empty( $options['team_btn'] ) ? $options['team_btn'] : '';
        $team_link = ! empty( $options['team_btn_url'] ) ? $options['team_btn_url'] : '';
        
        if ( empty( $content_details ) ) {
            return;
        } 
        ?> 
         
        <div id="kompany_team_section" class="relative page-section same-background">
            <div class="wrapper">
                <div class="section-header-wrapper">
                    <?php if( !empty( $team_title ) ): ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $team_title ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif;

                    if( !empty( $team_sub_title ) ):
                        ?>

                    <div class="section-content">
                        <p><?php echo esc_html( $team_sub_title ); ?></p>
                    </div>

                <?php endif; ?>

                <?php if( !empty( $team_link ) && !empty( $team_btn ) ): ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $team_link ); ?>" class="btn"><?php echo esc_html( $team_btn ); ?></a>
                    </div>
                <?php endif; ?>
            </div> <!-- .section-header -->

            <div class="team-section-wrapper">
                <div class="col-3">

                <?php $i=1; foreach ($content_details as $content ): ?>

                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ; ?>');">
                            </div>

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>" tabindex="0"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                    <?php if( !empty( $options['team_position_'.$i] ) ): ?>
                                        <span class="team-position"><?php echo esc_html( $options['team_position_'.$i] ) ; ?></span>
                                    <?php endif; ?>
                                </header>
                            </div><!-- .entry-container -->
                        </article>

                    <?php $i++; endforeach; ?>

                </div><!-- col-3 -->

                <?php if( !empty( $team_link ) && !empty( $team_btn ) ): ?>

                    <div class="read-more">
                        <a href="<?php echo esc_url( $team_link ); ?>" class="btn"><?php echo esc_html( $team_btn ); ?></a>
                    </div>

                <?php endif; ?>

            </div><!-- team-section-wrapper -->
        </div><!-- .wrapper -->
    </div><!-- #about -->

    <?php }
endif;